cocoalib: Computations in commutative algebra
=============================================

Description
-----------

CoCoA is a program to compute with numbers and polynomials.

License
-------

-  GPL v3


Upstream Contact
----------------

-  Authors: http://cocoa.dima.unige.it/research/
-  Email: cocoa@dima.unige.it
-  Website: http://cocoa.dima.unige.it/
-  Releases: http://cocoa.dima.unige.it/cocoalib/
